@@ -38,8 +38,8 @@
 #' @export
 estimate_lavaan_ten_berge <- function (fit) {
   X <- lavaan::lavInspect(fit, "data")
-  i.means <- fit@SampleStats@mean[[1]]
-  i.sds <- sqrt(fit@SampleStats@var[[1]])
+  i.means <- colMeans(X)
+  i.sds <- sqrt(diag(lavaan::lavInspect(fit, "sampstat")$cov))
   Lambda_mat <- lavaan::lavInspect(fit, what = "std.lv")$lambda
   Phi_mat <- matrix(lavaan::lavInspect(fit, what = "cor.lv"), ncol(Lambda_mat))
   calc_ten_berge_scores(X, Lambda_mat, Phi_mat, i.means, i.sds)
