@@ -27,6 +27,22 @@ return_mod_scores <- function(OOS_composite_scores,
 }
 
 one_stage_predict <- function(pls_model, testData, technique) {
+
+  # First reappend the testData to the trainData to get fulldata (do not duplicate rows)
+  no_int_mmvars <- pls_model$mmVariables[!grepl("\\*", pls_model$mmVariables)]
+  fulldata <- pls_model$data[,no_int_mmvars]
+  fulldata[rownames(testData),no_int_mmvars] <- testData[,no_int_mmvars]
+
+  suppressMessages(fullmodel <- seminr::estimate_pls(data =fulldata,
+                                                     measurement_model = pls_model$measurement_model,
+                                                     structural_model = pls_model$structural_model,
+                                                     inner_weights = pls_model$inner_weights,
+                                                     missing = pls_model$settings$missing,
+                                                     missing_value = pls_model$settings$missing_value,
+                                                     maxIt = pls_model$settings$maxIt,
+                                                     stopCriterion = pls_model$settings$stopCriterion))
+  actual_star <- fullmodel$construct_scores
+
   #Extract Measurements needed for Predictions
   normData <- testData[,pls_model$mmVariables]
 
@@ -54,25 +70,36 @@ one_stage_predict <- function(pls_model, testData, technique) {
   #Prepare return pls_model
   predictResults <- list(testData = testData[,pls_model$mmVariables],
                          predicted_items = predictedMeasurements[,pls_model$mmVariables],
-                         item_residuals = residuals)
+                         item_residuals = residuals,
+                         predicted_composite_scores = predicted_construct_scores,
+                         composite_residuals = (actual_star[rownames(testData),] - predicted_construct_scores),
+                         actual_star = actual_star[rownames(testData),])
 
   class(predictResults) <- "predicted_seminr_model"
   return(predictResults)
 }
 
 two_stage_predict <- function(pls_model, testData, technique) {
-  actual_star <- estimate_actual_star(pls_model = pls_model,
-                                      train_data = pls_model$rawdata,
-                                      testData = testData)
+  # First reappend the testData to the trainData to get fulldata (do not duplicate rows)
+  no_int_mmvars <- pls_model$mmVariables[!grepl("\\*", pls_model$mmVariables)]
+  fulldata <- pls_model$data[,no_int_mmvars]
+  fulldata[rownames(testData),no_int_mmvars] <- testData[,no_int_mmvars]
+  suppressMessages(fullmodel <- seminr::estimate_pls(data =fulldata,
+                                                     measurement_model = pls_model$measurement_model,
+                                                     structural_model = pls_model$structural_model,
+                                                     inner_weights = pls_model$inner_weights,
+                                                     missing = pls_model$settings$missing,
+                                                     missing_value = pls_model$settings$missing_value,
+                                                     maxIt = pls_model$settings$maxIt,
+                                                     stopCriterion = pls_model$settings$stopCriterion))
+  actual_star <- fullmodel$construct_scores
+
   # collect all interactions
   interactions <- pls_model$constructs[grepl("\\*", pls_model$constructs)]
 
   # parse interactions to get the iv, mv, and indicator name
   int_list <- lapply(interactions,parse_interactions)
 
-  # identify the indicators that do not take part in the interaction
-  no_int_mmvars <- pls_model$mmVariables[!grepl("\\*", pls_model$mmVariables)]
-
   # identify the training data
   train_data <- pls_model$rawdata
 
@@ -146,8 +173,10 @@ two_stage_predict <- function(pls_model, testData, technique) {
   #Prepare return Object
   predictResults <- list(testData = testData[,no_int_mmvars],
                          predicted_items = predictedMeasurements[,no_int_mmvars],
-                         item_residuals = residuals[,no_int_mmvars])
-
+                         item_residuals = residuals[,no_int_mmvars],
+                         predicted_composite_scores = predicted_construct_scores,
+                         composite_residuals = (actual_star[rownames(testData),] - predicted_construct_scores),
+                         actual_star = actual_star[rownames(testData),])
   class(predictResults) <- "predicted_seminr_model"
   return(predictResults)
 }
@@ -255,10 +284,6 @@ predict_pls <- function(model, technique = predict_DA, noFolds = NULL, reps = NU
     message("There is no published solution for applying PLSpredict to higher-order-models")
     return()
   }
-  # if (!is.null(model$interaction)) {
-  #   message("There is no published solution for applying PLSpredict to moderated models")
-  #   return()
-  # }
   # Get endogenous item names
   endogenous_items <- c(unlist(sapply(unique(model$smMatrix[,2]), function(x) model$mmMatrix[model$mmMatrix[, "construct"] == x,"measurement"]), use.names = FALSE))
 
@@ -298,7 +323,12 @@ predict_pls <- function(model, technique = predict_DA, noFolds = NULL, reps = NU
   }
 
   # Allocate results
-  results <- list(PLS_out_of_sample = PLS_predicted_outsample_item[,endogenous_items],
+  results <- list(
+    composites = list(
+      composite_out_of_sample = pred_matrices$out_of_sample_construct[rownames(model$data),],
+      composite_in_sample = pred_matrices$in_sample_construct[rownames(model$data),],
+      actuals_star = model$construct_scores[rownames(model$data),]),
+    items = list(PLS_out_of_sample = PLS_predicted_outsample_item[,endogenous_items],
                   PLS_in_sample = PLS_predicted_insample_item[,endogenous_items],
                   lm_out_of_sample = LM_predicted_outsample_item,
                   lm_in_sample = LM_predicted_insample_item,
@@ -306,8 +336,8 @@ predict_pls <- function(model, technique = predict_DA, noFolds = NULL, reps = NU
                   PLS_out_of_sample_residuals = (ordered_data[rownames(model$data),endogenous_items] - PLS_predicted_outsample_item[,endogenous_items]),
                   PLS_in_sample_residuals = (ordered_data[rownames(model$data),endogenous_items] - PLS_predicted_insample_item[,endogenous_items]),
                   lm_out_of_sample_residuals = (ordered_data[rownames(model$data),endogenous_items] - LM_predicted_outsample_item),
-                  lm_in_sample_residuals = (ordered_data[rownames(model$data),endogenous_items] - LM_predicted_insample_item))
-
+                  lm_in_sample_residuals = (ordered_data[rownames(model$data),endogenous_items] - LM_predicted_insample_item)),
+    model = model)
   class(results) <- "predict_pls_model"
   return(results)
 }
@@ -317,19 +347,19 @@ item_metrics <- function(pls_prediction_kfold) {
 
   # Genereate IS PLS metrics
   PLS_item_prediction_metrics_IS <- convert_to_table_output(
-    apply(pls_prediction_kfold$PLS_in_sample_residuals, 2, prediction_metrics))
+    apply(pls_prediction_kfold$items$PLS_in_sample_residuals, 2, prediction_metrics))
 
   # Generate OOS PLS metrics
   PLS_item_prediction_metrics_OOS <- convert_to_table_output(
-    apply(pls_prediction_kfold$PLS_out_of_sample_residuals, 2, prediction_metrics))
+    apply(pls_prediction_kfold$items$PLS_out_of_sample_residuals, 2, prediction_metrics))
 
   # Generate IS LM metrics
   LM_item_prediction_metrics_IS <- convert_to_table_output(
-    apply(pls_prediction_kfold$lm_in_sample_residuals, 2, prediction_metrics))
+    apply(pls_prediction_kfold$items$lm_in_sample_residuals, 2, prediction_metrics))
 
   # Generate OOS LM metrics
   LM_item_prediction_metrics_OOS <- convert_to_table_output(
-    apply(pls_prediction_kfold$lm_out_of_sample_residuals, 2, prediction_metrics))
+    apply(pls_prediction_kfold$items$lm_out_of_sample_residuals, 2, prediction_metrics))
 
   # Assign rownames to matrices
   rownames(PLS_item_prediction_metrics_IS) <- rownames(PLS_item_prediction_metrics_OOS) <- rownames(LM_item_prediction_metrics_OOS) <- c("RMSE","MAE")
@@ -418,34 +448,36 @@ in_and_out_sample_predictions <- function(x, folds, ordered_data, model,techniqu
   testingData <- ordered_data[testIndexes, ]
   trainingData <- ordered_data[-testIndexes, ]
   no_int_mmvars <- model$mmVariables[!grepl("\\*", model$mmVariables)]
+
   # Create matrices for return data
   PLS_predicted_outsample_construct <- matrix(0,nrow = nrow(ordered_data),ncol = length(model$constructs),dimnames = list(rownames(ordered_data),model$constructs))
   PLS_predicted_insample_construct <- matrix(0,nrow = nrow(ordered_data),ncol = length(model$constructs),dimnames = list(rownames(ordered_data),model$constructs))
   PLS_predicted_outsample_item <- matrix(0,nrow = nrow(ordered_data),ncol = length(no_int_mmvars),dimnames = list(rownames(ordered_data),no_int_mmvars))
   PLS_predicted_insample_item <- matrix(0,nrow = nrow(ordered_data),ncol = length(no_int_mmvars),dimnames = list(rownames(ordered_data),no_int_mmvars))
-
-  # identify the indicators that do not take part in the interaction
   PLS_predicted_insample_item_residuals <- matrix(0,nrow = nrow(ordered_data),ncol = length(no_int_mmvars),dimnames = list(rownames(ordered_data),no_int_mmvars))
   #PLS prediction on testset model
   suppressMessages(train_model <- estimate_pls(data = trainingData,
-                                                       measurement_model = model$measurement_model,
-                                                       structural_model = model$smMatrix,
-                                                       inner_weights = model$inner_weights,
-                                                       missing = model$settings$missing,
-                                                       missing_value = model$settings$missing_value,
-                                                       maxIt = model$settings$maxIt,
-                                                       stopCriterion = model$settings$stopCriterion))
+                                               measurement_model = model$measurement_model,
+                                               structural_model = model$smMatrix,
+                                               inner_weights = model$inner_weights,
+                                               missing = model$settings$missing,
+                                               missing_value = model$settings$missing_value,
+                                               maxIt = model$settings$maxIt,
+                                               stopCriterion = model$settings$stopCriterion))
   test_predictions <- stats::predict(object = train_model,
                                      testData = testingData,
                                      technique = technique)
 
+  PLS_predicted_outsample_construct[testIndexes,] <-  test_predictions$predicted_composite_scores
   PLS_predicted_outsample_item[testIndexes,] <- test_predictions$predicted_items
 
+
   #PLS prediction on trainset model
   train_predictions <- stats::predict(object = train_model,
                                       testData = trainingData,
                                       technique = technique)
 
+  PLS_predicted_insample_construct[trainIndexes,] <- train_predictions$predicted_composite_scores
   PLS_predicted_insample_item[trainIndexes,] <- train_predictions$predicted_items
   PLS_predicted_insample_item_residuals[trainIndexes,] <- as.matrix(train_predictions$item_residuals)
 
@@ -470,7 +502,9 @@ in_and_out_sample_predictions <- function(x, folds, ordered_data, model,techniqu
   lmprediction_out_sample <- do.call(cbind, lm_holder[((1:(length(unique(model$smMatrix[,2]))*2))[1:(length(unique(model$smMatrix[,2]))*2)%%2==0])])
   lmprediction_in_sample_residuals[trainIndexes,] <- as.matrix(ordered_data[trainIndexes,as.vector(endogenous_items)]) - lmprediction_in_sample[trainIndexes,as.vector(endogenous_items)]
 
-  return(list(PLS_predicted_insample_item = PLS_predicted_insample_item,
+  return(list(PLS_predicted_insample = PLS_predicted_insample_construct,
+              PLS_predicted_outsample = PLS_predicted_outsample_construct,
+              PLS_predicted_insample_item = PLS_predicted_insample_item,
               PLS_predicted_outsample_item = PLS_predicted_outsample_item,
               LM_predicted_insample_item = lmprediction_in_sample,
               LM_predicted_outsample_item = lmprediction_out_sample,
@@ -492,13 +526,14 @@ prediction_matrices <- function(noFolds, ordered_data, model,technique, cores) {
         # Create cluster
         suppressWarnings(ifelse(is.null(cores), cl <- parallel::makeCluster(parallel::detectCores()), cl <- parallel::makeCluster(cores)))
 
-        # generate_lm_predictions <- generate_lm_predictions
-        # predict_lm_matrices <- predict_lm_matrices
         # Export variables and functions to cluster
         parallel::clusterExport(cl=cl, varlist=c("generate_lm_predictions",
-                                                 "predict_lm_matrices"), envir=environment())
+                                                 "predict_lm_matrices",
+                                                 "standardize_data",
+                                                 "unstandardize_data"), envir=environment())
+        #parallel::clusterEvalQ(cl=cl,expr = "library(PLSpredict)")
 
-        # Execute the bootstrap
+                # Execute the bootstrap
         utils::capture.output(matrices <- parallel::parSapply(cl,1:noFolds,in_and_out_sample_predictions,folds = folds,
                                                               ordered_data = ordered_data,
                                                               model = model,
@@ -512,19 +547,31 @@ prediction_matrices <- function(noFolds, ordered_data, model,technique, cores) {
       }
 
       # collect the odd and even numbered matrices from the matrices return object
-      in_sample_item_matrix <- do.call(cbind, matrices[(1:(noFolds*6))[1:(noFolds*6)%%6==1]])
-      out_sample_item_matrix <- do.call(cbind, matrices[(1:(noFolds*6))[1:(noFolds*6)%%6==2]])
-      in_sample_lm_matrix <- do.call(cbind, matrices[(1:(noFolds*6))[1:(noFolds*6)%%6==3]])
-      out_sample_lm_matrix <- do.call(cbind, matrices[(1:(noFolds*6))[1:(noFolds*6)%%6==4]])
-      PLS_in_sample_item_residuals <- do.call(cbind, matrices[(1:(noFolds*6))[1:(noFolds*6)%%6==5]])
-      LM_in_sample_item_residuals <- do.call(cbind, matrices[(1:(noFolds*6))[1:(noFolds*6)%%6==0]])
-
       no_int_mmvars <- model$mmVariables[!grepl("\\*", model$mmVariables)]
+      in_sample_construct_matrix <- do.call(cbind, matrices[(1:(noFolds*8))[1:(noFolds*8)%%8==1]])
+      out_sample_construct_matrix <- do.call(cbind, matrices[(1:(noFolds*8))[1:(noFolds*8)%%8==2]])
+      in_sample_item_matrix <- do.call(cbind, matrices[(1:(noFolds*8))[1:(noFolds*8)%%8==3]])
+      out_sample_item_matrix <- do.call(cbind, matrices[(1:(noFolds*8))[1:(noFolds*8)%%8==4]])
+      in_sample_lm_matrix <- do.call(cbind, matrices[(1:(noFolds*8))[1:(noFolds*8)%%8==5]])
+      out_sample_lm_matrix <- do.call(cbind, matrices[(1:(noFolds*8))[1:(noFolds*8)%%8==6]])
+      PLS_in_sample_item_residuals <- do.call(cbind, matrices[(1:(noFolds*8))[1:(noFolds*8)%%8==7]])
+      LM_in_sample_item_residuals <- do.call(cbind, matrices[(1:(noFolds*8))[1:(noFolds*8)%%8==0]])
+
+      # mean the in-sample construct predictions by row
+      average_insample_construct <- sapply(1:length(model$constructs), mean_rows, matrix = in_sample_construct_matrix,
+                                           noFolds = noFolds,
+                                           constructs = model$constructs)
+
       # mean the in-sample item predictions by row
       average_insample_item <- sapply(1:length(no_int_mmvars), mean_rows, matrix = in_sample_item_matrix,
                                       noFolds = noFolds,
                                       constructs = no_int_mmvars)
 
+      # sum the out-sample construct predictions by row
+      average_outsample_construct <- sapply(1:length(model$constructs), sum_rows, matrix = out_sample_construct_matrix,
+                                            noFolds = noFolds,
+                                            constructs = model$constructs)
+
       # sum the out-sample item predictions by row
       average_outsample_item <- sapply(1:length(no_int_mmvars), sum_rows, matrix = out_sample_item_matrix,
                                        noFolds = noFolds,
@@ -552,10 +599,13 @@ prediction_matrices <- function(noFolds, ordered_data, model,technique, cores) {
                                                         noFolds = noFolds,
                                                         constructs = endogenous_items))
 
-      colnames(average_insample_item) <- colnames(average_outsample_item) <- colnames(average_insample_pls_item_residuals) <- no_int_mmvars
+      colnames(average_insample_construct) <- colnames(average_outsample_construct) <- model$constructs
+      colnames(average_insample_item) <- colnames(average_insample_pls_item_residuals) <- colnames(average_outsample_item) <- no_int_mmvars
       colnames(average_insample_lm) <- colnames(average_outsample_lm) <- colnames(average_insample_lm_item_residuals) <- endogenous_items
 
-      return(list(out_of_sample_item = average_outsample_item,
+      return(list(out_of_sample_construct = average_outsample_construct,
+                  in_sample_construct = average_insample_construct,
+                  out_of_sample_item = average_outsample_item,
                   in_sample_item = average_insample_item,
                   out_of_sample_lm_item = average_outsample_lm,
                   in_sample_lm_item = average_insample_lm,
@@ -606,7 +656,7 @@ generate_lm_predictions <- function(x, model, ordered_data, testIndexes, endogen
   in_sample_matrix <- matrix(0,nrow = nrow(ordered_data), ncol = length(dependant_items), dimnames = list(rownames(ordered_data),dependant_items))
   out_sample_matrix <- matrix(0,nrow = nrow(ordered_data), ncol = length(dependant_items), dimnames = list(rownames(ordered_data),dependant_items))
 
-  # Select the correct independent variables to be icluded in independent matrix
+  # Select the correct independent variables to be included in independent matrix
   # for predict_DA this would be the indicators of the direct antecedents only
   # for predict_EA this would be the indicators of the earliest antecedents only
   if (identical(technique, predict_DA)) {
@@ -619,14 +669,17 @@ generate_lm_predictions <- function(x, model, ordered_data, testIndexes, endogen
   }
   independant_matrix <- ordered_data[ , focal_construct_antecedent_items,drop = F]
   dependant_matrix <- as.matrix(ordered_data[,dependant_items, drop = F])
+
   # Create independant items matrices - training and testing
   indepTestData <- independant_matrix[testIndexes, ,drop = F]
   indepTrainData <- independant_matrix[-testIndexes, ,drop = F]
 
   # Create dependant matrices - training and testing
-  depTestData <- as.matrix(dependant_matrix[testIndexes, ,drop = F])
-
-  #depTestData <- as.matrix(dependant_matrix[testIndexes, ])
+  # if (length(testIndexes) == 1) {
+    # depTestData <- t(as.matrix(dependant_matrix[testIndexes, ,drop = F]))
+  # } else {
+    depTestData <- as.matrix(dependant_matrix[testIndexes, ,drop = F])
+  # }
   depTrainData <- as.matrix(dependant_matrix[-testIndexes, ])
   colnames(depTrainData) <- colnames(depTestData) <- dependant_items
 
